@@ -38,7 +38,6 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gtksourceview/gtksourceiter.h>
 
 #include "gedit-settings.h"
 #include "gedit-document.h"
@@ -2146,7 +2145,7 @@ gedit_document_search_forward (GeditDocument     *doc,
 			       GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-	GtkSourceSearchFlags search_flags;
+	GtkTextSearchFlags search_flags;
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
@@ -2172,22 +2171,22 @@ gedit_document_search_forward (GeditDocument     *doc,
 	else
 		iter = *start;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 		
 	while (!found)
 	{
-		found = gtk_source_iter_forward_search (&iter,
-							doc->priv->search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	end);
-      	               	
+		found = gtk_text_iter_forward_search (&iter,
+		                                      doc->priv->search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      end);
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
 			found = gtk_text_iter_starts_word (&m_start) && 
@@ -2227,7 +2226,7 @@ gedit_document_search_backward (GeditDocument     *doc,
 				GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-	GtkSourceSearchFlags search_flags;
+	GtkTextSearchFlags search_flags;
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
@@ -2253,22 +2252,22 @@ gedit_document_search_backward (GeditDocument     *doc,
 	else
 		iter = *end;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 
 	while (!found)
 	{
-		found = gtk_source_iter_backward_search (&iter,
-							 doc->priv->search_text, 
-							 search_flags,
-                        	                	 &m_start, 
-                        	                	 &m_end,
-                                	               	 start);
-      	               	
+		found = gtk_text_iter_backward_search (&iter,
+		                                       doc->priv->search_text,
+		                                       search_flags,
+		                                       &m_start,
+		                                       &m_end,
+		                                       start);
+
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
 			found = gtk_text_iter_starts_word (&m_start) && 
@@ -2302,7 +2301,7 @@ gedit_document_replace_all (GeditDocument       *doc,
 	GtkTextIter iter;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
-	GtkSourceSearchFlags search_flags = 0;
+	GtkTextSearchFlags search_flags = 0;
 	gboolean found = TRUE;
 	gint cont = 0;
 	gchar *search_text;
@@ -2327,11 +2326,11 @@ gedit_document_replace_all (GeditDocument       *doc,
 
 	gtk_text_buffer_get_start_iter (buffer, &iter);
 
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 
 	replace_text_len = strlen (replace_text);
@@ -2354,12 +2353,12 @@ gedit_document_replace_all (GeditDocument       *doc,
 
 	do
 	{
-		found = gtk_source_iter_forward_search (&iter,
-							search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	NULL);
+		found = gtk_text_iter_forward_search (&iter,
+		                                      search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      NULL);
 
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (flags))
 		{
@@ -2570,8 +2569,8 @@ search_region (GeditDocument *doc,
 {
 	GtkTextIter iter;
 	GtkTextIter m_start;
-	GtkTextIter m_end;	
-	GtkSourceSearchFlags search_flags = 0;
+	GtkTextIter m_end;
+	GtkTextSearchFlags search_flags = 0;
 	gboolean found = TRUE;
 
 	GtkTextBuffer *buffer;	
@@ -2635,11 +2634,11 @@ search_region (GeditDocument *doc,
 
 	iter = *start;
 		
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
 	if (!GEDIT_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
 	}
 	
 	do
@@ -2647,13 +2646,13 @@ search_region (GeditDocument *doc,
 		if ((end != NULL) && gtk_text_iter_is_end (end))
 			end = NULL;
 			
-		found = gtk_source_iter_forward_search (&iter,
-							doc->priv->search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	end);
-				
+		found = gtk_text_iter_forward_search (&iter,
+		                                      doc->priv->search_text,
+		                                      search_flags,
+		                                      &m_start,
+		                                      &m_end,
+		                                      end);
+
 		iter = m_end;
 						      	               	
 		if (found && GEDIT_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
