@@ -82,6 +82,23 @@ typedef enum
 
 } GeditSearchFlags;
 
+/*
+ * NOTE: when adding a new compression type, make sure to update:
+ *   1) The document loader to support it
+ *   2) gedit_document_compression_type_for_display
+ */
+
+/**
+ * GeditDocumentCompressionType:
+ * @GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE: save file in plain text.
+ * @GEDIT_DOCUMENT_COMPRESSION_TYPE_GZIP: save file using gzip compression.
+ */
+typedef enum
+{
+	GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE,
+	GEDIT_DOCUMENT_COMPRESSION_TYPE_GZIP
+} GeditDocumentCompressionType;
+
 /**
  * GeditDocumentSaveFlags:
  * @GEDIT_DOCUMENT_SAVE_IGNORE_MTIME: save file despite external modifications.
@@ -126,9 +143,10 @@ struct _GeditDocumentClass
 
 	/* Document load */
 	void (* load)			(GeditDocument       *document,
-					 const gchar         *uri,
+					 GFile               *location,
 					 const GeditEncoding *encoding,
 					 gint                 line_pos,
+					 gint                 column_pos,
 					 gboolean             create);
 
 	void (* loading)		(GeditDocument    *document,
@@ -139,10 +157,12 @@ struct _GeditDocumentClass
 					 const GError     *error);
 
 	/* Document save */
-	void (* save)			(GeditDocument          *document,
-					 const gchar            *uri,
-					 const GeditEncoding    *encoding,
-					 GeditDocumentSaveFlags  flags);
+	void (* save)			(GeditDocument                *document,
+					 GFile                        *location,
+					 const GeditEncoding          *encoding,
+					 GeditDocumentNewlineType      newline_type,
+					 GeditDocumentCompressionType  compression_type,
+					 GeditDocumentSaveFlags        flags);
 
 	void (* saving)			(GeditDocument    *document,
 					 goffset	   size,
@@ -177,43 +197,53 @@ GType		 gedit_document_get_type      	(void) G_GNUC_CONST;
 GeditDocument   *gedit_document_new 		(void);
 
 GFile		*gedit_document_get_location	(GeditDocument       *doc);
-
-gchar		*gedit_document_get_uri 	(GeditDocument       *doc);
-void		 gedit_document_set_uri		(GeditDocument       *doc,
-						 const gchar 	     *uri);
+void		 gedit_document_set_location	(GeditDocument       *doc,
+						 GFile               *location);
 
 gchar		*gedit_document_get_uri_for_display
 						(GeditDocument       *doc);
 gchar		*gedit_document_get_short_name_for_display
 					 	(GeditDocument       *doc);
 
+void		 gedit_document_set_short_name_for_display
+						(GeditDocument       *doc,
+						 const gchar         *short_name);
+
 gchar		*gedit_document_get_content_type
 					 	(GeditDocument       *doc);
 
+void		 gedit_document_set_content_type
+					 	(GeditDocument       *doc,
+					 	 const gchar         *content_type);
+
 gchar		*gedit_document_get_mime_type 	(GeditDocument       *doc);
 
 gboolean	 gedit_document_get_readonly 	(GeditDocument       *doc);
 
 void		 gedit_document_load 		(GeditDocument       *doc,
-						 const gchar         *uri,
+						 GFile               *location,
 						 const GeditEncoding *encoding,
 						 gint                 line_pos,
-						 gboolean             create); 
+						 gint                 column_pos,
+						 gboolean             create);
 
-gboolean	 gedit_document_insert_file	(GeditDocument       *doc,
-						 GtkTextIter         *iter, 
-						 const gchar         *uri, 
-						 const GeditEncoding *encoding);
+void		 gedit_document_load_stream	(GeditDocument       *doc,
+						 GInputStream        *stream,
+						 const GeditEncoding *encoding,
+						 gint                 line_pos,
+						 gint                 column_pos);
 
 gboolean	 gedit_document_load_cancel	(GeditDocument       *doc);
 
 void		 gedit_document_save 		(GeditDocument       *doc,
 						 GeditDocumentSaveFlags flags);
 
-void		 gedit_document_save_as 	(GeditDocument       *doc,	
-						 const gchar         *uri, 
-						 const GeditEncoding *encoding,
-						 GeditDocumentSaveFlags flags);
+void		 gedit_document_save_as 	(GeditDocument                *doc,
+						 GFile                        *location,
+						 const GeditEncoding          *encoding,
+						 GeditDocumentNewlineType      newline_type,
+						 GeditDocumentCompressionType  compression_type,
+						 GeditDocumentSaveFlags        flags);
 
 gboolean	 gedit_document_is_untouched 	(GeditDocument       *doc);
 gboolean	 gedit_document_is_untitled 	(GeditDocument       *doc);
@@ -225,9 +255,9 @@ gboolean	 gedit_document_get_deleted	(GeditDocument       *doc);
 gboolean	 gedit_document_goto_line 	(GeditDocument       *doc, 
 						 gint                 line);
 
-gboolean	 gedit_document_goto_line_offset(GeditDocument *doc,
-						 gint           line,
-						 gint           line_offset);
+gboolean	 gedit_document_goto_line_offset(GeditDocument       *doc,
+						 gint                 line,
+						 gint                 line_offset);
 
 void		 gedit_document_set_search_text	(GeditDocument       *doc,
 						 const gchar         *text,
@@ -271,17 +301,17 @@ void		 gedit_document_set_enable_search_highlighting
 gboolean	 gedit_document_get_enable_search_highlighting
 						(GeditDocument       *doc);
 
-void		 gedit_document_set_newline_type (GeditDocument           *doc,
-						  GeditDocumentNewlineType newline_type);
-
 GeditDocumentNewlineType
-		 gedit_document_get_newline_type (GeditDocument *doc);
+		 gedit_document_get_newline_type (GeditDocument      *doc);
 
-gchar		*gedit_document_get_metadata	(GeditDocument *doc,
-						 const gchar   *key);
+GeditDocumentCompressionType
+		 gedit_document_get_compression_type (GeditDocument  *doc);
 
-void		 gedit_document_set_metadata	(GeditDocument *doc,
-						 const gchar   *first_key,
+gchar		*gedit_document_get_metadata	(GeditDocument       *doc,
+						 const gchar         *key);
+
+void		 gedit_document_set_metadata	(GeditDocument       *doc,
+						 const gchar         *first_key,
 						 ...);
 
 /* 
@@ -314,6 +344,11 @@ void		_gedit_document_search_region   (GeditDocument       *doc,
 #define GEDIT_SEARCH_SET_CASE_SENSITIVE(sflags,state) ((state == TRUE) ? \
 (sflags |= GEDIT_SEARCH_CASE_SENSITIVE) : (sflags &= ~GEDIT_SEARCH_CASE_SENSITIVE))
 
+/**
+ * GeditMountOperationFactory: (skip)
+ * @doc:
+ * @userdata:
+ */
 typedef GMountOperation *(*GeditMountOperationFactory)(GeditDocument *doc, 
 						       gpointer       userdata);
 
@@ -328,3 +363,5 @@ GMountOperation
 G_END_DECLS
 
 #endif /* __GEDIT_DOCUMENT_H__ */
+
+/* ex:ts=8:noet: */
