@@ -33,6 +33,7 @@ typedef struct _OverlayChild
 {
 	GtkWidget *child;
 	GdkGravity gravity;
+	guint      offset;
 
 	guint fixed_position : 1;
 	guint is_animated : 1;
@@ -50,23 +51,30 @@ struct _GeditOverlayPrivate
 	glong          vadjustment_signal_id;
 
 	GeditTheatricsStage *stage;
+
+	/* GtkScrollablePolicy needs to be checked when
+	 * driving the scrollable adjustment values */
+	guint hscroll_policy : 1;
+	guint vscroll_policy : 1;
 };
 
 enum
 {
 	PROP_0,
-	PROP_MAIN_WIDGET
+	PROP_MAIN_WIDGET,
+	PROP_HADJUSTMENT,
+	PROP_VADJUSTMENT,
+	PROP_HSCROLL_POLICY,
+	PROP_VSCROLL_POLICY
 };
 
-enum
-{
-	SET_SCROLL_ADJUSTMENTS,
-	LAST_SIGNAL
-};
+static void	gedit_overlay_set_hadjustment		(GeditOverlay  *overlay,
+							 GtkAdjustment *adjustment);
+static void	gedit_overlay_set_vadjustment		(GeditOverlay  *overlay,
+							 GtkAdjustment *adjustment);
 
-static guint signals[LAST_SIGNAL] = { 0 };
-
-G_DEFINE_TYPE (GeditOverlay, gedit_overlay, GTK_TYPE_CONTAINER)
+G_DEFINE_TYPE_WITH_CODE (GeditOverlay, gedit_overlay, GTK_TYPE_CONTAINER,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
 
 static void
 free_container_child (OverlayChild *child)
@@ -79,7 +87,8 @@ add_toplevel_widget (GeditOverlay *overlay,
                      GtkWidget    *widget,
                      gboolean      fixed_position,
                      gboolean      is_animated,
-                     GdkGravity    gravity)
+                     GdkGravity    gravity,
+                     guint         offset)
 {
 	OverlayChild *child = g_slice_new (OverlayChild);
 
@@ -87,6 +96,7 @@ add_toplevel_widget (GeditOverlay *overlay,
 	child->gravity = gravity;
 	child->fixed_position = fixed_position;
 	child->is_animated = is_animated;
+	child->offset = offset;
 
 	gtk_widget_set_parent (widget, GTK_WIDGET (overlay));
 
@@ -139,12 +149,46 @@ gedit_overlay_get_property (GObject    *object,
                             GParamSpec *pspec)
 {
 	GeditOverlay *overlay = GEDIT_OVERLAY (object);
+	GeditOverlayPrivate *priv = overlay->priv;
 
 	switch (prop_id)
 	{
 		case PROP_MAIN_WIDGET:
-			g_value_set_object (value, overlay->priv->main_widget);
+			g_value_set_object (value, priv->main_widget);
 			break;
+
+		case PROP_HADJUSTMENT:
+			g_value_set_object (value, priv->hadjustment);
+			break;
+
+		case PROP_VADJUSTMENT:
+			g_value_set_object (value, priv->vadjustment);
+			break;
+
+		case PROP_HSCROLL_POLICY:
+			if (GTK_IS_SCROLLABLE (priv->main_widget))
+			{
+				g_value_set_enum (value,
+				                  gtk_scrollable_get_hscroll_policy (GTK_SCROLLABLE (priv->main_widget)));
+			}
+			else
+			{
+				g_value_set_enum (value, priv->hscroll_policy);
+			}
+			break;
+
+		case PROP_VSCROLL_POLICY:
+			if (GTK_IS_SCROLLABLE (priv->main_widget))
+			{
+				g_value_set_enum (value,
+				                  gtk_scrollable_get_vscroll_policy (GTK_SCROLLABLE (priv->main_widget)));
+			}
+			else
+			{
+				g_value_set_enum (value, priv->vscroll_policy);
+			}
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -158,17 +202,54 @@ gedit_overlay_set_property (GObject      *object,
                             GParamSpec   *pspec)
 {
 	GeditOverlay *overlay = GEDIT_OVERLAY (object);
+	GeditOverlayPrivate *priv = overlay->priv;
 
 	switch (prop_id)
 	{
 		case PROP_MAIN_WIDGET:
-		{
 			overlay->priv->main_widget = g_value_get_object (value);
 			add_toplevel_widget (overlay,
 			                     overlay->priv->main_widget,
-			                     TRUE, FALSE, GDK_GRAVITY_STATIC);
+			                     TRUE, FALSE, GDK_GRAVITY_STATIC,
+			                     0);
 			break;
-		}
+
+		case PROP_HADJUSTMENT:
+			gedit_overlay_set_hadjustment (overlay,
+						       g_value_get_object (value));
+			break;
+
+		case PROP_VADJUSTMENT:
+			gedit_overlay_set_vadjustment (overlay,
+						       g_value_get_object (value));
+			break;
+
+		case PROP_HSCROLL_POLICY:
+			if (GTK_IS_SCROLLABLE (priv->main_widget))
+			{
+				gtk_scrollable_set_hscroll_policy (GTK_SCROLLABLE (priv->main_widget),
+				                                   g_value_get_enum (value));
+			}
+			else
+			{
+				priv->hscroll_policy = g_value_get_enum (value);
+				gtk_widget_queue_resize (GTK_WIDGET (overlay));
+			}
+			break;
+
+		case PROP_VSCROLL_POLICY:
+			if (GTK_IS_SCROLLABLE (priv->main_widget))
+			{
+				gtk_scrollable_set_vscroll_policy (GTK_SCROLLABLE (priv->main_widget),
+				                                   g_value_get_enum (value));
+			}
+			else
+			{
+				priv->vscroll_policy = g_value_get_enum (value);
+				gtk_widget_queue_resize (GTK_WIDGET (overlay));
+			}
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -216,11 +297,12 @@ set_children_positions (GeditOverlay *overlay)
 
 	for (l = overlay->priv->children; l != NULL; l = g_slist_next (l))
 	{
+		GeditOverlayPrivate *priv = overlay->priv;
 		OverlayChild *child = (OverlayChild *)l->data;
 		GtkRequisition req;
 		GtkAllocation alloc;
 
-		if (child->child == overlay->priv->main_widget)
+		if (child->child == priv->main_widget)
 			continue;
 
 		gtk_widget_get_preferred_size (child->child, &req, NULL);
@@ -230,7 +312,7 @@ set_children_positions (GeditOverlay *overlay)
 		{
 			/* The gravity is the inverse of the place we want */
 			case GDK_GRAVITY_SOUTH_WEST:
-				alloc.x = overlay->priv->main_alloc.width - req.width;
+				alloc.x = priv->main_alloc.width - req.width - child->offset;
 				alloc.y = 0;
 				break;
 			default:
@@ -240,8 +322,8 @@ set_children_positions (GeditOverlay *overlay)
 
 		if (!child->fixed_position)
 		{
-			alloc.x *= gtk_adjustment_get_value (overlay->priv->hadjustment);
-			alloc.y *= gtk_adjustment_get_value (overlay->priv->vadjustment);
+			alloc.x *= gtk_adjustment_get_value (priv->hadjustment);
+			alloc.y *= gtk_adjustment_get_value (priv->vadjustment);
 		}
 
 		alloc.width = req.width;
@@ -274,7 +356,7 @@ gedit_overlay_add (GtkContainer *overlay,
                    GtkWidget    *widget)
 {
 	add_toplevel_widget (GEDIT_OVERLAY (overlay), widget,
-	                     FALSE, FALSE, GDK_GRAVITY_STATIC);
+	                     FALSE, FALSE, GDK_GRAVITY_STATIC, 0);
 }
 
 static void
@@ -330,46 +412,84 @@ adjustment_value_changed (GtkAdjustment *adjustment,
 }
 
 static void
-gedit_overlay_set_scroll_adjustments (GeditOverlay  *overlay,
-                                      GtkAdjustment *hadjustment,
-                                      GtkAdjustment *vadjustment)
+gedit_overlay_set_hadjustment (GeditOverlay  *overlay,
+                               GtkAdjustment *adjustment)
 {
-	if (overlay->priv->hadjustment != NULL)
+	GeditOverlayPrivate *priv = overlay->priv;
+
+	if (adjustment && priv->vadjustment == adjustment)
+		return;
+
+	if (priv->hadjustment != NULL)
 	{
-		g_signal_handler_disconnect (overlay->priv->hadjustment,
-		                             overlay->priv->hadjustment_signal_id);
+		g_signal_handler_disconnect (priv->hadjustment,
+		                             priv->hadjustment_signal_id);
+		g_object_unref (priv->hadjustment);
 	}
 
-	if (overlay->priv->vadjustment != NULL)
+	if (adjustment == NULL)
 	{
-		g_signal_handler_disconnect (overlay->priv->vadjustment,
-		                             overlay->priv->vadjustment_signal_id);
+		adjustment = gtk_adjustment_new (0.0, 0.0, 0.0,
+		                                 0.0, 0.0, 0.0);
 	}
 
-	if (hadjustment != NULL)
+	priv->hadjustment_signal_id =
+		g_signal_connect (adjustment,
+		                  "value-changed",
+		                  G_CALLBACK (adjustment_value_changed),
+		                  overlay);
+
+	priv->hadjustment = g_object_ref_sink (adjustment);
+
+	if (GTK_IS_SCROLLABLE (priv->main_widget))
 	{
-		overlay->priv->hadjustment_signal_id =
-			g_signal_connect (hadjustment,
-			                  "value-changed",
-			                  G_CALLBACK (adjustment_value_changed),
-			                  overlay);
+		g_object_set (priv->main_widget,
+		              "hadjustment", adjustment,
+		              NULL);
+
 	}
 
-	if (vadjustment != NULL)
+	g_object_notify (G_OBJECT (overlay), "hadjustment");
+}
+
+static void
+gedit_overlay_set_vadjustment (GeditOverlay  *overlay,
+                               GtkAdjustment *adjustment)
+{
+	GeditOverlayPrivate *priv = overlay->priv;
+
+	if (adjustment && priv->vadjustment == adjustment)
+		return;
+
+	if (priv->vadjustment != NULL)
 	{
-		overlay->priv->vadjustment_signal_id =
-			g_signal_connect (vadjustment,
-			                  "value-changed",
-			                  G_CALLBACK (adjustment_value_changed),
-			                  overlay);
+		g_signal_handler_disconnect (priv->vadjustment,
+		                             priv->vadjustment_signal_id);
+		g_object_unref (priv->vadjustment);
 	}
 
-	overlay->priv->hadjustment = hadjustment;
-	overlay->priv->vadjustment = vadjustment;
+	if (adjustment == NULL)
+	{
+		adjustment = gtk_adjustment_new (0.0, 0.0, 0.0,
+		                                 0.0, 0.0, 0.0);
+	}
 
-	gtk_widget_set_scroll_adjustments (overlay->priv->main_widget,
-	                                   hadjustment,
-	                                   vadjustment);
+	overlay->priv->vadjustment_signal_id =
+		g_signal_connect (adjustment,
+		                  "value-changed",
+		                  G_CALLBACK (adjustment_value_changed),
+		                  overlay);
+
+	priv->vadjustment = g_object_ref_sink (adjustment);
+
+	if (GTK_IS_SCROLLABLE (priv->main_widget))
+	{
+		g_object_set (priv->main_widget,
+		              "vadjustment", adjustment,
+		              NULL);
+	}
+
+	g_object_notify (G_OBJECT (overlay), "vadjustment");
 }
 
 static void
@@ -392,8 +512,6 @@ gedit_overlay_class_init (GeditOverlayClass *klass)
 	container_class->forall = gedit_overlay_forall;
 	container_class->child_type = gedit_overlay_child_type;
 
-	klass->set_scroll_adjustments = gedit_overlay_set_scroll_adjustments;
-
 	g_object_class_install_property (object_class, PROP_MAIN_WIDGET,
 	                                 g_param_spec_object ("main-widget",
 	                                                      "Main Widget",
@@ -403,17 +521,18 @@ gedit_overlay_class_init (GeditOverlayClass *klass)
 	                                                      G_PARAM_CONSTRUCT_ONLY |
 	                                                      G_PARAM_STATIC_STRINGS));
 
-	signals[SET_SCROLL_ADJUSTMENTS] =
-		g_signal_new ("set-scroll-adjustments",
-		              G_OBJECT_CLASS_TYPE (object_class),
-		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		              G_STRUCT_OFFSET (GeditOverlayClass, set_scroll_adjustments),
-		              NULL, NULL,
-		              gedit_marshal_VOID__OBJECT_OBJECT,
-		              G_TYPE_NONE, 2,
-		              GTK_TYPE_ADJUSTMENT,
-		              GTK_TYPE_ADJUSTMENT);
-	widget_class->set_scroll_adjustments_signal = signals[SET_SCROLL_ADJUSTMENTS];
+	g_object_class_override_property (object_class,
+	                                  PROP_HADJUSTMENT,
+	                                  "hadjustment");
+	g_object_class_override_property (object_class,
+	                                  PROP_VADJUSTMENT,
+	                                  "vadjustment");
+	g_object_class_override_property (object_class,
+	                                  PROP_HSCROLL_POLICY,
+	                                  "hscroll-policy");
+	g_object_class_override_property (object_class,
+	                                  PROP_VSCROLL_POLICY,
+	                                  "vscroll-policy");
 
 	g_type_class_add_private (object_class, sizeof (GeditOverlayPrivate));
 }
@@ -551,7 +670,8 @@ gedit_overlay_add_animated_widget (GeditOverlay                       *overlay,
                                    GeditTheatricsChoreographerEasing   easing,
                                    GeditTheatricsChoreographerBlocking blocking,
                                    GtkOrientation                      orientation,
-                                   GdkGravity                          gravity)
+                                   GdkGravity                          gravity,
+                                   guint                               offset)
 {
 	GeditTheatricsAnimatedWidget *anim_widget;
 	GeditTheatricsActor *actor;
@@ -577,5 +697,5 @@ gedit_overlay_add_animated_widget (GeditOverlay                       *overlay,
 	                                                 duration);
 
 	add_toplevel_widget (overlay, GTK_WIDGET (anim_widget), TRUE,
-	                     TRUE, gravity);
+	                     TRUE, gravity, offset);
 }
