@@ -45,26 +45,19 @@ typedef struct _GeditSettingsPrivate	GeditSettingsPrivate;
 
 struct _GeditSettings
 {
-	GSettings parent;
+	GObject parent;
 
 	GeditSettingsPrivate *priv;
 };
 
 struct _GeditSettingsClass
 {
-	GSettingsClass parent_class;
+	GObjectClass parent_class;
 };
 
-typedef enum {
-	GEDIT_TOOLBAR_SYSTEM = 0,
-	GEDIT_TOOLBAR_ICONS,
-	GEDIT_TOOLBAR_ICONS_AND_TEXT,
-	GEDIT_TOOLBAR_ICONS_BOTH_HORIZ
-} GeditToolbarSetting;
-
 GType			 gedit_settings_get_type			(void) G_GNUC_CONST;
 
-GSettings		*gedit_settings_new				(void);
+GObject			*gedit_settings_new				(void);
 
 GeditLockdownMask	 gedit_settings_get_lockdown			(GeditSettings *gs);
 
