@@ -31,6 +31,8 @@
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
 #define __GEDIT_WINDOW_PRIVATE_H__
 
+#include <libpeas/peas-extension-set.h>
+
 #include "gedit/gedit-window.h"
 #include "gedit-message-bus.h"
 #include "gedit-settings.h"
@@ -62,6 +64,7 @@ struct _GeditWindowPrivate
 	GtkWidget      *language_combo;
 	
 	GeditMessageBus *message_bus;	
+	PeasExtensionSet *extensions;
 
 	/* Widgets for fullscreen mode */
 	GtkWidget      *fullscreen_controls;
@@ -85,14 +88,13 @@ struct _GeditWindowPrivate
 	GtkActionGroup *always_sensitive_action_group;
 	GtkActionGroup *close_action_group;
 	GtkActionGroup *quit_action_group;
-	GtkActionGroup *panes_action_group;
+	GtkActionGroup *panels_action_group;
 	GtkActionGroup *languages_action_group;
 	GtkActionGroup *documents_list_action_group;
 	guint           documents_list_menu_ui_id;
 	GtkWidget      *toolbar;
 	GtkWidget      *toolbar_recent_menu;
 	GtkWidget      *menubar;
-	GeditToolbarSetting toolbar_style;
 
 	/* recent files */
 	GtkActionGroup *recents_action_group;
