@@ -49,12 +49,13 @@
 #define FILEBROWSER_FILTER_MODE		"filter-mode"
 #define FILEBROWSER_FILTER_PATTERN	"filter-pattern"
 
-#define NAUTILUS_BASE_SETTINGS		"org.gnome.Nautilus.preferences"
+#define NAUTILUS_BASE_SETTINGS		"org.gnome.nautilus.preferences"
+#define NAUTILUS_FALLBACK_SETTINGS	"org.gnome.gedit.plugins.filebrowser.nautilus"
 #define NAUTILUS_CLICK_POLICY_KEY	"click-policy"
 #define NAUTILUS_ENABLE_DELETE_KEY	"enable-delete"
 #define NAUTILUS_CONFIRM_TRASH_KEY	"confirm-trash"
 
-#define TERMINAL_BASE_SETTINGS		"org.gnome.Desktop.Applications.Terminal"
+#define TERMINAL_BASE_SETTINGS		"org.gnome.desktop.default-applications.terminal"
 #define TERMINAL_EXEC_KEY		"exec"
 
 #define GEDIT_FILE_BROWSER_PLUGIN_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_FILE_BROWSER_PLUGIN, GeditFileBrowserPluginPrivate))
@@ -80,6 +81,12 @@ struct _GeditFileBrowserPluginPrivate
 	guint			confirm_trash_handle;
 };
 
+enum
+{
+	PROP_0,
+	PROP_WINDOW
+};
+
 static void gedit_window_activatable_iface_init	(GeditWindowActivatableInterface *iface);
 
 static void on_location_activated_cb     (GeditFileBrowserWidget        *widget,
@@ -95,16 +102,10 @@ static void on_model_set_cb              (GeditFileBrowserView          *widget,
 static void on_virtual_root_changed_cb   (GeditFileBrowserStore         *model,
                                           GParamSpec                    *param,
                                           GeditFileBrowserPlugin        *plugin);
-static void on_filter_mode_changed_cb    (GeditFileBrowserStore         *model,
-                                          GParamSpec                    *param,
-                                          GeditFileBrowserPlugin        *plugin);
 static void on_rename_cb		 (GeditFileBrowserStore         *model,
 					  GFile                         *oldfile,
 					  GFile                         *newfile,
 					  GeditWindow                   *window);
-static void on_filter_pattern_changed_cb (GeditFileBrowserWidget        *widget,
-                                          GParamSpec                    *param,
-                                          GeditFileBrowserPlugin        *plugin);
 static void on_tab_added_cb              (GeditWindow                   *window,
                                           GeditTab                      *tab,
                                           GeditFileBrowserPlugin        *plugin);
@@ -117,7 +118,7 @@ static gboolean on_confirm_no_trash_cb   (GeditFileBrowserWidget        *widget,
                                           GeditWindow                   *window);
 
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserPlugin,
-				filetree_plugin,
+				gedit_file_browser_plugin,
 				PEAS_TYPE_EXTENSION_BASE,
 				0,
 				G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_WINDOW_ACTIVATABLE,
@@ -130,18 +131,50 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserPlugin,
 				_gedit_file_browser_widget_register_type	(type_module);		\
 )
 
-static void
-filetree_plugin_init (GeditFileBrowserPlugin *plugin)
+static GSettings *
+settings_try_new (const gchar *schema)
 {
-	plugin->priv = GEDIT_FILE_BROWSER_PLUGIN_GET_PRIVATE (plugin);
+	const gchar * const * schemas;
+	GSettings *settings = NULL;
 
-	plugin->priv->settings = g_settings_new (FILEBROWSER_BASE_SETTINGS);
-	plugin->priv->nautilus_settings = g_settings_new (NAUTILUS_BASE_SETTINGS);
-	plugin->priv->terminal_settings = g_settings_new (TERMINAL_BASE_SETTINGS);
+	schemas = g_settings_list_schemas ();
+
+	if (schemas == NULL)
+	{
+		return NULL;
+	}
+
+	for (; *schemas != NULL; schemas++)
+	{
+		if (g_strcmp0 (*schemas, schema) == 0)
+		{
+			settings = g_settings_new (schema);
+			break;
+		}
+	}
+
+	return settings;
 }
 
 static void
-filetree_plugin_dispose (GObject *object)
+gedit_file_browser_plugin_init (GeditFileBrowserPlugin *plugin)
+{
+	
+
+	plugin->priv = GEDIT_FILE_BROWSER_PLUGIN_GET_PRIVATE (plugin);
+
+	plugin->priv->settings = g_settings_new (FILEBROWSER_BASE_SETTINGS);
+	plugin->priv->terminal_settings = g_settings_new (TERMINAL_BASE_SETTINGS);
+	plugin->priv->nautilus_settings = settings_try_new (NAUTILUS_BASE_SETTINGS);
+
+	if (plugin->priv->nautilus_settings == NULL)
+	{
+		plugin->priv->nautilus_settings = g_settings_new (NAUTILUS_FALLBACK_SETTINGS);
+	}
+}
+
+static void
+gedit_file_browser_plugin_dispose (GObject *object)
 {
 	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (object);
 
@@ -163,7 +196,53 @@ filetree_plugin_dispose (GObject *object)
 		plugin->priv->terminal_settings = NULL;
 	}
 
-	G_OBJECT_CLASS (filetree_plugin_parent_class)->dispose (object);
+	if (plugin->priv->window != NULL)
+	{
+		g_object_unref (plugin->priv->window);
+		plugin->priv->window = NULL;
+	}
+
+	G_OBJECT_CLASS (gedit_file_browser_plugin_parent_class)->dispose (object);
+}
+
+static void
+gedit_file_browser_plugin_set_property (GObject      *object,
+                                        guint         prop_id,
+                                        const GValue *value,
+                                        GParamSpec   *pspec)
+{
+	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			plugin->priv->window = GEDIT_WINDOW (g_value_dup_object (value));
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
+static void
+gedit_file_browser_plugin_get_property (GObject    *object,
+                                        guint       prop_id,
+                                        GValue     *value,
+                                        GParamSpec *pspec)
+{
+	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			g_value_set_object (value, plugin->priv->window);
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
 }
 
 static void
@@ -261,51 +340,6 @@ restore_default_location (GeditFileBrowserPlugin *plugin)
 	g_free (virtual_root);
 }
 
-static void
-restore_filter (GeditFileBrowserPlugin *plugin)
-{
-	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *filter_mode;
-	GeditFileBrowserStoreFilterMode mode;
-	gchar *pattern;
-
-	/* Get filter_mode */
-	filter_mode = g_settings_get_string (priv->settings,
-					     FILEBROWSER_FILTER_MODE);
-
-	/* Filter mode */
-	mode = gedit_file_browser_store_filter_mode_get_default ();
-
-	if (filter_mode != NULL)
-	{
-		if (strcmp (filter_mode, "hidden") == 0)
-			mode = GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_HIDDEN;
-		else if (strcmp (filter_mode, "binary") == 0)
-			mode = GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_BINARY;
-		else if (strcmp (filter_mode, "hidden-and-binary") == 0 ||
-		         strcmp (filter_mode, "binary-and-hidden") == 0)
-			mode = GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_HIDDEN |
-			       GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_BINARY;
-		else if (strcmp (filter_mode, "none") == 0 ||
-			 *filter_mode == '\0')
-			mode = GEDIT_FILE_BROWSER_STORE_FILTER_MODE_NONE;
-	}
-
-	/* Set the filter mode */
-	gedit_file_browser_store_set_filter_mode (
-		gedit_file_browser_widget_get_browser_store (priv->tree_widget),
-		mode);
-
-	pattern = g_settings_get_string (priv->settings,
-					 FILEBROWSER_FILTER_PATTERN);
-
-	gedit_file_browser_widget_set_filter_pattern (priv->tree_widget,
-	                                              pattern);
-
-	g_free (filter_mode);
-	g_free (pattern);
-}
-
 static GeditFileBrowserViewClickPolicy
 click_policy_from_string (gchar const *click_policy)
 {
@@ -562,8 +596,7 @@ static GtkActionEntry extra_single_selection_actions[] = {
 };
 
 static void
-add_popup_ui (GeditWindow            *window,
-	      GeditFileBrowserPlugin *plugin)
+add_popup_ui (GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
 	GtkUIManager *manager;
@@ -586,7 +619,7 @@ add_popup_ui (GeditWindow            *window,
 	gtk_action_group_add_actions (action_group,
 				      extra_single_selection_actions,
 				      G_N_ELEMENTS (extra_single_selection_actions),
-				      window);
+				      priv->window);
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 	priv->single_selection_action_group = action_group;
 
@@ -603,8 +636,7 @@ add_popup_ui (GeditWindow            *window,
 }
 
 static void
-remove_popup_ui (GeditWindow            *window,
-		 GeditFileBrowserPlugin *plugin)
+remove_popup_ui (GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
 	GtkUIManager *manager;
@@ -620,13 +652,12 @@ remove_popup_ui (GeditWindow            *window,
 }
 
 static void
-gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable,
-					GeditWindow            *window)
+gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPluginPrivate *priv = GEDIT_FILE_BROWSER_PLUGIN (activatable)->priv;
 	GeditDocument *doc;
 
-	doc = gedit_window_get_active_document (window);
+	doc = gedit_window_get_active_document (priv->window);
 
 	gtk_action_set_sensitive (gtk_action_group_get_action (priv->action_group,
 	                                                       "SetActiveRoot"),
@@ -634,18 +665,17 @@ gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable,
 }
 
 static void
-gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
-				    GeditWindow            *window)
+gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (activatable);
-	GeditFileBrowserPluginPrivate *priv = plugin->priv;
+	GeditFileBrowserPluginPrivate *priv;
 	GeditPanel *panel;
 	GtkWidget *image;
 	GdkPixbuf *pixbuf;
 	GeditFileBrowserStore *store;
 	gchar *data_dir;
 
-	priv->window = window;
+	priv = plugin->priv;
 
 	data_dir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (activatable));
 	priv->tree_widget = GEDIT_FILE_BROWSER_WIDGET (gedit_file_browser_widget_new (data_dir));
@@ -653,16 +683,11 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 
 	g_signal_connect (priv->tree_widget,
 			  "location-activated",
-			  G_CALLBACK (on_location_activated_cb), window);
+			  G_CALLBACK (on_location_activated_cb), priv->window);
 
 	g_signal_connect (priv->tree_widget,
 			  "error", G_CALLBACK (on_error_cb), plugin);
 
-	g_signal_connect (priv->tree_widget,
-	                  "notify::filter-pattern",
-	                  G_CALLBACK (on_filter_pattern_changed_cb),
-	                  plugin);
-
 	g_signal_connect (priv->tree_widget,
 	                  "confirm-delete",
 	                  G_CALLBACK (on_confirm_delete_cb),
@@ -671,7 +696,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	g_signal_connect (priv->tree_widget,
 	                  "confirm-no-trash",
 	                  G_CALLBACK (on_confirm_no_trash_cb),
-	                  window);
+	                  priv->window);
 
 	g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW
 			  (gedit_file_browser_widget_get_browser_view
@@ -680,7 +705,13 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 			  G_CALLBACK (on_selection_changed_cb),
 			  plugin);
 
-	panel = gedit_window_get_side_panel (window);
+	g_settings_bind (priv->settings,
+	                 FILEBROWSER_FILTER_PATTERN,
+	                 priv->tree_widget,
+	                 FILEBROWSER_FILTER_PATTERN,
+	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
+	panel = gedit_window_get_side_panel (priv->window);
 	pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("system-file-manager",
 	                                                     GTK_ICON_SIZE_MENU);
 
@@ -702,10 +733,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	                      image);
 	gtk_widget_show (GTK_WIDGET (priv->tree_widget));
 
-	add_popup_ui (window, plugin);
-
-	/* Restore filter options */
-	restore_filter (plugin);
+	add_popup_ui (plugin);
 
 	/* Install nautilus preferences */
 	install_nautilus_prefs (plugin);
@@ -717,35 +745,36 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	                  plugin);
 
 	store = gedit_file_browser_widget_get_browser_store (priv->tree_widget);
+
+	g_settings_bind (priv->settings,
+	                 "filter-mode",
+	                 store,
+	                 "filter-mode",
+	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
 	g_signal_connect (store,
 	                  "notify::virtual-root",
 	                  G_CALLBACK (on_virtual_root_changed_cb),
 	                  plugin);
 
-	g_signal_connect (store,
-	                  "notify::filter-mode",
-	                  G_CALLBACK (on_filter_mode_changed_cb),
-	                  plugin);
-
 	g_signal_connect (store,
 			  "rename",
 			  G_CALLBACK (on_rename_cb),
-			  window);
+			  priv->window);
 
-	g_signal_connect (window,
+	g_signal_connect (priv->window,
 	                  "tab-added",
 	                  G_CALLBACK (on_tab_added_cb),
 	                  plugin);
 
 	/* Register messages on the bus */
-	gedit_file_browser_messages_register (window, priv->tree_widget);
+	gedit_file_browser_messages_register (priv->window, priv->tree_widget);
 
-	gedit_file_browser_plugin_update_state (activatable, window);
+	gedit_file_browser_plugin_update_state (activatable);
 }
 
 static void
-gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
-				      GeditWindow            *window)
+gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (activatable);
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
@@ -753,10 +782,10 @@ gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
 
 
 	/* Unregister messages from the bus */
-	gedit_file_browser_messages_unregister (window);
+	gedit_file_browser_messages_unregister (priv->window);
 
 	/* Disconnect signals */
-	g_signal_handlers_disconnect_by_func (window,
+	g_signal_handlers_disconnect_by_func (priv->window,
 	                                      G_CALLBACK (on_tab_added_cb),
 	                                      plugin);
 
@@ -778,18 +807,22 @@ gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
 					     priv->confirm_trash_handle);
 	}
 
-	remove_popup_ui (window, plugin);
+	remove_popup_ui (plugin);
 
-	panel = gedit_window_get_side_panel (window);
+	panel = gedit_window_get_side_panel (priv->window);
 	gedit_panel_remove_item (panel, GTK_WIDGET (priv->tree_widget));
 }
 
 static void
-filetree_plugin_class_init (GeditFileBrowserPluginClass *klass)
+gedit_file_browser_plugin_class_init (GeditFileBrowserPluginClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->dispose = filetree_plugin_dispose;
+	object_class->dispose = gedit_file_browser_plugin_dispose;
+	object_class->set_property = gedit_file_browser_plugin_set_property;
+	object_class->get_property = gedit_file_browser_plugin_get_property;
+
+	g_object_class_override_property (object_class, PROP_WINDOW, "window");
 
 	g_type_class_add_private (object_class,
 				  sizeof (GeditFileBrowserPluginPrivate));
@@ -804,7 +837,7 @@ gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface)
 }
 
 static void
-filetree_plugin_class_finalize (GeditFileBrowserPluginClass *klass)
+gedit_file_browser_plugin_class_finalize (GeditFileBrowserPluginClass *klass)
 {
 }
 
@@ -894,43 +927,6 @@ on_model_set_cb (GeditFileBrowserView   *widget,
 	                        GEDIT_IS_FILE_BROWSER_STORE (model));
 }
 
-static void
-on_filter_mode_changed_cb (GeditFileBrowserStore  *model,
-                           GParamSpec             *param,
-                           GeditFileBrowserPlugin *plugin)
-{
-	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	GeditFileBrowserStoreFilterMode mode;
-
-	mode = gedit_file_browser_store_get_filter_mode (model);
-
-	if ((mode & GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_HIDDEN) &&
-	    (mode & GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_BINARY))
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_MODE,
-		                       "hidden-and-binary");
-	}
-	else if (mode & GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_HIDDEN)
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_MODE,
-		                       "hidden");
-	}
-	else if (mode & GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_BINARY)
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_MODE,
-		                       "binary");
-	}
-	else
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_MODE,
-		                       "none");
-	}
-}
-
 static void
 on_rename_cb (GeditFileBrowserStore *store,
 	      GFile                 *oldfile,
@@ -985,32 +981,6 @@ on_rename_cb (GeditFileBrowserStore *store,
 	g_list_free (documents);
 }
 
-static void
-on_filter_pattern_changed_cb (GeditFileBrowserWidget *widget,
-                              GParamSpec             *param,
-                              GeditFileBrowserPlugin *plugin)
-{
-	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *pattern;
-
-	g_object_get (G_OBJECT (widget), "filter-pattern", &pattern, NULL);
-
-	if (pattern == NULL)
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_PATTERN,
-		                       "");
-	}
-	else
-	{
-		g_settings_set_string (priv->settings,
-		                       FILEBROWSER_FILTER_PATTERN,
-		                       pattern);
-	}
-
-	g_free (pattern);
-}
-
 static void
 on_virtual_root_changed_cb (GeditFileBrowserStore  *store,
                             GParamSpec             *param,
@@ -1199,7 +1169,7 @@ on_confirm_delete_cb (GeditFileBrowserWidget *widget,
 G_MODULE_EXPORT void
 peas_register_types (PeasObjectModule *module)
 {
-	filetree_plugin_register_type (G_TYPE_MODULE (module));
+	gedit_file_browser_plugin_register_type (G_TYPE_MODULE (module));
 
 	peas_object_module_register_extension_type (module,
 						    GEDIT_TYPE_WINDOW_ACTIVATABLE,
